import ReactEcharts from 'echarts-for-react';
import { get, map, merge } from 'lodash';
import { useEffect, useMemo, useState } from 'react';
const BothwayBar = () => {
  let top = 60;
  let bottom = 60;
  let data = {
    female: {
      name: '女性',
      data: [
        {
          value: 5,
          label: '小于1岁',
        },
        {
          value: 12,
          label: '1 ～ 9 岁',
        },
        {
          value: 10,
          label: '10 ～ 19 岁',
        },
        {
          value: 7,
          label: '20 ～ 29 岁',
        },
        {
          value: 32,
          label: '30 ～ 39 岁',
        },
        {
          value: 40,
          label: '40 ～ 49 岁',
        },
        {
          value: 28,
          label: '50 ～ 59 岁',
        },
        {
          value: 34,
          label: '大于60岁',
        },
      ],
    },
    male: {
      name: '男性',
      data: [
        {
          value: 5,
          label: '小于1岁',
        },
        {
          value: 19,
          label: '1 ～ 9 岁',
        },
        {
          value: 23,
          label: '10 ～ 19 岁',
        },
        {
          value: 43,
          label: '20 ～ 29 岁',
        },
        {
          value: 34,
          label: '30 ～ 39 岁',
        },
        {
          value: 53,
          label: '40 ～ 49 岁',
        },
        {
          value: 12,
          label: '50 ～ 59 岁',
        },
        {
          value: 34,
          label: '大于60岁',
        },
      ],
    },
  };
  const [yAxisData, setyAxisData] = useState([]);
  useEffect(() => {
    const list = [];
    data?.female?.data?.forEach((item) => {
      list.push(item.label);
    });
    setyAxisData([...list]);
  }, []);

  const option = useMemo(() => {
    return {
      tooltip: {
        show: true,
        trigger: 'axis',
        axisPointer: {
          type: 'shadow',
        },
      },
      // legend: {
      //     left: 'center',
      //     bottom: 24,
      //     itemWidth: 15,
      //     itemHeight: 11,
      //     itemGap: 20,
      //     borderRadius: 4,
      //     textStyle: {
      //         color: '#262C41',
      //         fontSize: 14
      //     },
      //     data: legendData
      // },
      grid: [
        {
          left: '12%',
          width: '28%',
          containLabel: true,
          bottom,
        },
        {
          left: '52%',
          width: '0%',
          bottom: bottom + 16,
        },
        {
          right: '12%',
          width: '28%',
          containLabel: true,
          bottom,
        },
      ].map((item) =>
        merge(
          {
            top,
          },
          item,
        ),
      ),
      xAxis: [
        {
          type: 'value',
          inverse: true,
          axisLabel: {
            show: true,
          },
          axisLine: {
            show: false,
          },
          axisTick: {
            show: false,
          },
          splitLine: {
            show: false,
          },
        },
        {
          gridIndex: 1,
          show: true,
        },
        {
          gridIndex: 2,
          type: 'value',
          axisLabel: {
            show: true,
          },
          axisLine: {
            show: false,
          },
          axisTick: {
            show: false,
          },
          splitLine: {
            show: false,
          },
        },
      ].map((item) =>
        merge(item, {
          axisLabel: {
            color: '#949AA8',
            margin: 0,
          },
          splitLine: {
            lineStyle: {
              color: '#E0E0E0',
              type: 'dashed',
            },
          },
        }),
      ),
      yAxis: [
        {
          position: 'right',
          axisLabel: {
            show: false,
          },
          axisLine: {
            show: false,
          },
        },
        {
          gridIndex: 1,
          position: 'center',
          axisLabel: {
            align: 'center',
            padding: [8, 0, 0, 0],
            fontSize: 16,
            color: `rgb(203, 237, 255)`,
          },
          axisLine: {
            show: false,
          },
        },
        {
          gridIndex: 2,
          position: 'left',
          axisLabel: {
            show: false,
          },
          axisLine: {
            show: false,
          },
        },
      ].map((item) => {
        return merge(item, {
          type: 'category',
          inverse: false,
          // axisLine: {
          //   lineStyle: {
          //     color: '#E0E0E0',
          //   },
          // },
          axisTick: {
            show: false,
          },
          data: yAxisData,
        });
      }),
      series: [
        {
          name: get(data, 'male.name'),
          label: {
            position: 'left',
          },
          itemStyle: {
            color: 'rgb(50, 177, 255)',
            //   barBorderRadius: [4, 0, 0, 4],
          },
          data: map(get(data, 'male.data'), (d) => d.value),
        },
        {
          xAxisIndex: 2,
          yAxisIndex: 2,
          name: get(data, 'female.name'),
          label: {
            position: 'right',
          },
          itemStyle: {
            color: 'rgb(255, 155, 93)',
            //   barBorderRadius: [0, 4, 4, 0],
          },
          data: map(get(data, 'female.data'), (d) => d.value),
        },
      ].map((item) =>
        merge(item, {
          type: 'bar',
          barWidth: 11,
          label: {
            show: true,
            //   fontFamily: 'Rubik-Medium',
            fontSize: 16,
            distance: 10,
            color: '#fff',
          },
        }),
      ),
    };
  }, [yAxisData]);

  return (
    <ReactEcharts
      option={option} // option：图表配置项
      style={{ width: '800px', height: '300px' }}
    />
  );
};

export default BothwayBar;
