import Tabs from '@/components/Tabs';
import { CaretDownOutlined, CaretUpOutlined } from '@ant-design/icons';
import { Flex, Progress, Space } from 'antd';
import { memo, useMemo } from 'react';
import { useGlobalModalServices } from '../../provider';
import LineCharts from '../AdministPunish/LineCharts';
import styles from './index.less';

/**行政处罚modal */
const AreaSynergy = () => {
  const { dispatch } = useGlobalModalServices();

  const items = useMemo(() => {
    return [
      {
        key: '2',
        name: '处置中',
        count: 456,
        unit: '件',
      },
      {
        key: '1',
        name: '超时',
        count: 12,
        unit: '件',
      },
      {
        key: '3',
        name: '已办结',
        count: 456,
        unit: '件',
      },
      {
        key: '3',
        name: '办结率',
        count: 456,
        unit: '%',
      },
    ];
  }, []);

  return (
    <div className={styles.container}>
      <div className={styles.leftWarp}>
        <div
          className={styles.dispose}
          onClick={() => {
         
          }}
        >
          <div className={styles.title}>
            <div className={styles.tLeft}>
              <span>巡查处置问题总数</span>
              <span className={styles.count}>4672</span>
              <span>件</span>
            </div>
            <div className={styles.tRignt}>
              <span>环比</span>
              <span>
                <CaretUpOutlined style={{ color: 'rgb(29, 187, 138)' }} />
                <CaretDownOutlined style={{ color: 'red' }} />
              </span>
              <span className={styles.count}>0.25</span>
              <span>%</span>
            </div>
          </div>
          <LineCharts
            data={[
              60, 50, 60, 70, 50, 70, 50, 60, 70, 50, 80, 50, 60, 70, 50, 60,
              50, 60, 70, 50,
            ]}
            style={{ width: 525, height: 80 }}
          />
        </div>

        <div className={styles.scoreType}>
          <div className={styles.title}>
            <span>高发类型TOP5</span>
          </div>

          <div className={styles.content}>
            {[{ percent: 80, value: 20, name: '占到经营' }].map(
              (item, index) => {
                return (
                  <div className={styles.litsItem} key={index}>
                    <Flex justify="space-between">
                      <div className={styles.name}>{item.name}</div>
                      <Space size={10} className={styles.numBox}>
                        <div className={styles.num}>
                          <span>{item?.value}</span>
                          <span>件</span>
                        </div>
                        <div className={styles.num}>
                          <span>{Number(item?.percent ?? 0).toFixed(2)}</span>
                          <span>%</span>
                        </div>
                      </Space>
                    </Flex>

                    <Progress
                      size={{ height: 15 }}
                      percent={item?.percent}
                      showInfo={false}
                      strokeColor={{ from: '#79FFD1', to: '#00B9FF' }}
                      status="active"
                    />
                  </div>
                );
              },
            )}
          </div>
        </div>
      </div>
      <div className={styles.rightWarp}>
        <div className={styles.infoWarp}>
          {items?.map((item) => {
            return (
              <div
                key={item.key}
                className={styles.items}
                onClick={() => {
                  dispatch.push('AreaSynergyList',{
                    title:`市区协调${item.name}事件列表`
                  });
                }}
              >
                <span className={styles.name}>{item?.name}</span>
                <div>
                  <span className={styles.count}>{item?.count}</span>
                  <span className={styles.unit}>{item?.unit}</span>
                </div>
              </div>
            );
          })}
        </div>

        <div className={styles.dispAreaTop5}>
          <div className={styles.title}>
            <span>处置区域数量TOP5</span>
            <Tabs
              style={{
                background: 'transparent',
                height: '30px',
              }}
              itemStyle={{
                borderRadius: '25px',
                background: 'rgba(7, 50, 93, 0.8)',
                fontSize: '16px',
                marginLeft: 8,
              }}
              onChange={() => {}}
              itemkey={'key'}
              items={[
                {
                  key: 'mainClass',
                  label: '全部',
                },
                {
                  key: 'subClass',
                  label: '中心城区',
                },
                {
                  key: 'sub1Class',
                  label: '城市新区',
                },
                {
                  key: 'sub1Cl1ass',
                  label: '郊区新城',
                },
              ]}
            />
          </div>

          <div className={styles.content}>
            {[{ percent: 80, value: 20, name: '高新区' }].map((item, index) => {
              return (
                <div className={styles.litsItem} key={index}>
                  <Flex justify="space-between">
                    <div className={styles.name}>{item.name}</div>
                    <Space size={10} className={styles.numBox}>
                      <div className={styles.num}>
                        <span>{item?.value}</span>
                        <span>件</span>
                      </div>
                      <div className={styles.num}>
                        <span>{Number(item?.percent ?? 0).toFixed(2)}</span>
                        <span>%</span>
                      </div>
                    </Space>
                  </Flex>

                  <Progress
                    size={{ height: 15 }}
                    percent={item?.percent}
                    showInfo={false}
                    strokeColor={{ from: '#79FFD1', to: '#00B9FF' }}
                    status="active"
                  />
                </div>
              );
            })}
          </div>
        </div>
      </div>
    </div>
  );
};
export default memo(AreaSynergy);
