import BlueTable from '@/components/BlueTable';
import Tabs from '@/components/Tabs';
import { CaretDownOutlined, CaretUpOutlined } from '@ant-design/icons';
import { Flex, Progress, Space } from 'antd';
import { memo, useMemo, useState } from 'react';
import { useGlobalModalServices } from '../../provider';
import LineCharts from '../AdministPunish/LineCharts';
import styles from './index.less';
import TimeLineCharts from './TimeLineCharts';

/**日常巡查modal */
const DyaPatrol = () => {
  const { dispatch } = useGlobalModalServices();
  const [activeKey, setActiveKey] = useState('1');
  const tp3List = useMemo(() => {
    return [
      {
        key: '2',
        name: '李守勇',
        count: 12,
        works: '西安路街道城管执法中队',
        bg: require('@/assets/images/administPunish/starBg2.png'),
        icon: require('@/assets/images/administPunish/star1.png'),
      },
      {
        key: '1',
        name: '李守勇',
        count: 12,
        works: '西安路街道城管执法中队',
        bg: require('@/assets/images/administPunish/starBg1.png'),
        icon: require('@/assets/images/administPunish/star2.png'),
      },
      {
        key: '3',
        name: '李守勇',
        count: 12,
        works: '西安路街道城管执法中队',
        bg: require('@/assets/images/administPunish/starBg3.png'),
        icon: require('@/assets/images/administPunish/star3.png'),
      },
    ];
  }, []);
  const top5Items = [
    {
      key: '1',
      label: '区域排行榜TOP5',
    },
    {
      key: '2',
      label: '部门排行榜TOP5',
    },
  ];
  return (
    <div className={styles.container}>
      <div className={styles.leftWarp}>
        <div
          className={styles.dispose}
          onClick={() => {
            dispatch.push('DyaPatrolList', {
              title: '巡查处置列表',
            });
          }}
        >
          <div className={styles.title}>
            <div className={styles.tLeft}>
              <span>巡查处置问题总数</span>
              <span className={styles.count}>4672</span>
              <span>件</span>
            </div>
            <div className={styles.tRignt}>
              <span>环比</span>
              <span>
                <CaretUpOutlined style={{ color: 'rgb(29, 187, 138)' }} />
                <CaretDownOutlined style={{ color: 'red' }} />
              </span>
              <span className={styles.count}>0.25</span>
              <span>%</span>
            </div>
          </div>
          <LineCharts
            data={[
              60, 50, 60, 70, 50, 70, 50, 60, 70, 50, 80, 50, 60, 70, 50, 60,
              50, 60, 70, 50,
            ]}
            style={{ width: 525, height: 80 }}
          />
        </div>

        <div className={styles.scoreType}>
          <div className={styles.title}>
            <span>高发类型TOP5</span>
            <Tabs
              style={{
                background: 'transparent',
                height: '30px',
                marginTop: 10,
              }}
              itemStyle={{
                borderRadius: '25px',
                background: 'rgba(7, 50, 93, 0.8)',
                fontSize: '16px',
                marginLeft: 8,
              }}
              onChange={() => {}}
              itemkey={'key'}
              items={[
                {
                  key: 'mainClass',
                  label: '大类',
                },
                {
                  key: 'subClass',
                  label: '小类',
                },
              ]}
            />
          </div>

          <div className={styles.content}>
            {[
              { percent: 80, value: 20, name: '占道经营' },
              { percent: 80, value: 20, name: '占道经营' },
              { percent: 80, value: 20, name: '占道经营' },
            ].map((item, index) => {
              return (
                <div className={styles.litsItem} key={index}>
                  <Flex justify="space-between">
                    <div className={styles.name}>{item.name}</div>
                    <Space size={10} className={styles.numBox}>
                      <div className={styles.num}>
                        <span>{item?.value}</span>
                        <span>件</span>
                      </div>
                      <div className={styles.num}>
                        <span>{Number(item?.percent ?? 0).toFixed(2)}</span>
                        <span>%</span>
                      </div>
                    </Space>
                  </Flex>

                  <Progress
                    size={{ height: 15 }}
                    percent={item?.percent}
                    showInfo={false}
                    strokeColor={{ from: '#79FFD1', to: '#00B9FF' }}
                    status="active"
                  />
                </div>
              );
            })}
          </div>
        </div>

        <div className={styles.timeFrame}>
          <div className={styles.title}>高发时段分析</div>
          <TimeLineCharts
            data={[
              60, 50, 60, 70, 50, 70, 50, 60, 70, 50, 80, 50, 60, 70, 50, 60,
              50, 60, 70, 50,
            ]}
            style={{ width: 525, height: 80 }}
          />
        </div>
      </div>
      <div className={styles.rightWarp}>
        <div className={styles.top3}>
          <div className={styles.title}>工作之星</div>
          <div className={styles.content}>
            {tp3List?.map((item) => {
              return (
                <div
                  className={styles.starItem}
                  style={{
                    backgroundImage: `url(${item.bg})`,
                    backgroundSize: '100% 100%',
                  }}
                >
                  <img src={item.icon} alt="" className={styles.img} />
                  <div className={styles.info}>
                    <span className={styles.name}>{item.name}</span>
                    <span className={styles.count}>{item.count}</span>
                    <span className={styles.unit}>件</span>
                  </div>
                  <div className={styles.works}>{item.works}</div>
                </div>
              );
            })}
          </div>
        </div>
        <div className={styles.areaTop5}>
          <div className={styles.tabs}>
            {top5Items?.map((item) => {
              return (
                <div
                  key={item.key}
                  onClick={() => {
                    setActiveKey(item.key);
                  }}
                  style={{
                    marginRight: 10,
                    color:
                      activeKey === item.key
                        ? 'rgb(255, 255, 255)'
                        : 'rgb(119, 168, 194)',
                  }}
                >
                  {item.label}
                </div>
              );
            })}
          </div>
          <Tabs
            style={{
              background: 'transparent',
              height: '30px',
              marginTop: 10,
            }}
            itemStyle={{
              borderRadius: '25px',
              background: 'rgba(7, 50, 93, 0.8)',
              fontSize: '16px',
              marginLeft: 8,
            }}
            onChange={() => {}}
            itemkey={'key'}
            items={[
              {
                key: 'mainClass',
                label: '全部',
              },
              {
                key: 'subClass',
                label: '中心城区',
              },
              {
                key: '1',
                label: '城市新区',
              },
              {
                key: '2',
                label: '郊区新城',
              },
            ]}
          />
          {activeKey === '1' ? (
            <div>
              <BlueTable
                //   dataSource={tableData?.data?.data?.records}
                scroll={{ y: 300 }}
                dataSource={[
                  {
                    wh: '523655411223',
                    type: '扬尘类',
                    ss: '80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂',
                    rq: '2023-03-01',
                  },

                  {
                    wh: '523655411223',
                    type: '扬尘类',
                    ss: '80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂',
                    rq: '2023-03-01',
                  },
                  {
                    wh: '523655411223',
                    type: '扬尘类',
                    ss: '80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂',
                    rq: '2023-03-01',
                  },
                  {
                    wh: '523655411223',
                    type: '扬尘类',
                    ss: '80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂',
                    rq: '2023-03-01',
                  },
                  {
                    wh: '523655411223',
                    type: '扬尘类',
                    ss: '80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂',
                    rq: '2023-03-01',
                  },
                ]}
                columns={[
                  {
                    title: '排名',
                    dataIndex: 'wh',
                    key: 'descgldw',
                    width: 100,
                    ellipsis: true,
                    render: (_: any, rows: any, index: number) => {
                      return (
                        <div className={styles.rankIng}>TOP{index + 1}</div>
                      );
                    },
                  },
                  {
                    title: '区域',
                    dataIndex: 'area',
                    key: 'area',
                    width: 150,
                    ellipsis: true,
                  },
                  {
                    title: '占比',
                    dataIndex: 'zb',
                    key: 'zb',
                    width: 120,
                    ellipsis: true,
                    render: () => {
                      return <div className={styles.proportion}>20%</div>;
                    },
                  },
                  {
                    title: '巡查处置问题数',
                    dataIndex: 'total',
                    key: 'total',
                    width: 200,
                    ellipsis: true,
                    render: () => {
                      return (
                        <div style={{ fontSize: 20, fontWeight: 700 }}>
                          16<span className={styles.tableUnit}>件</span>
                        </div>
                      );
                    },
                  },
                ]}
                pagination={false}
              />
            </div>
          ) : (
            <div>
              <BlueTable
                //   dataSource={tableData?.data?.data?.records}
                scroll={{ y: 300 }}
                dataSource={[
                  {
                    wh: '523655411223',
                    type: '扬尘类',
                    ss: '80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂',
                    rq: '2023-03-01',
                  },

                  {
                    wh: '523655411223',
                    type: '扬尘类',
                    ss: '80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂',
                    rq: '2023-03-01',
                  },
                  {
                    wh: '523655411223',
                    type: '扬尘类',
                    ss: '80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂',
                    rq: '2023-03-01',
                  },
                  {
                    wh: '523655411223',
                    type: '扬尘类',
                    ss: '80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂',
                    rq: '2023-03-01',
                  },
                  {
                    wh: '523655411223',
                    type: '扬尘类',
                    ss: '80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂80x公司在天府新区正兴街道云龙路保利XXXXXXX天府和颂',
                    rq: '2023-03-01',
                  },
                ]}
                columns={[
                  {
                    title: '排名',
                    dataIndex: 'wh',
                    key: 'descgldw',
                    width: 100,
                    ellipsis: true,
                    render: (_: any, rows: any, index: number) => {
                      return (
                        <div className={styles.rankIng}>TOP{index + 1}</div>
                      );
                    },
                  },
                  {
                    title: '上报部门',
                    dataIndex: 'area',
                    key: 'area',
                    width: 250,
                    ellipsis: true,
                  },
                  {
                    title: '所属区域',
                    dataIndex: 'area',
                    key: 'area',
                    width: 100,
                    ellipsis: true,
                  },
                  {
                    title: '占比',
                    dataIndex: 'zb',
                    key: 'zb',
                    width: 100,
                    ellipsis: true,
                    render: () => {
                      return <div className={styles.proportion}>20%</div>;
                    },
                  },
                  {
                    title: '巡查处置问题数',
                    dataIndex: 'total',
                    key: 'total',
                    width: 100,
                    ellipsis: true,
                    render: () => {
                      return (
                        <div style={{ fontSize: 20, fontWeight: 700 }}>
                          16<span className={styles.tableUnit}>件</span>
                        </div>
                      );
                    },
                  },
                ]}
                pagination={false}
              />
            </div>
          )}
        </div>
      </div>
    </div>
  );
};
export default memo(DyaPatrol);
