import Chart from '@/components/PieChart/Chart';
import Tabs from '@/components/Tabs';
import services from '@/services';
import { CaretDownOutlined, CaretUpOutlined } from '@ant-design/icons';
import { useRequest } from 'ahooks';
import { Flex, Progress, Space } from 'antd';
import dayjs from 'dayjs';
import { memo, useMemo } from 'react';
import { useGlobalModalServices } from '../../provider';
import LineCharts from '../AdministPunish/LineCharts';
import styles from './index.less';
import TimeLineCharts from './TimeLineCharts';

const SanitationDisp = (props: any) => {
  const { time } = props;
  const { dispatch } = useGlobalModalServices();
  //问题数
  const { data: sjzt } = useRequest(
    () =>
      services.DataBase.getSjdzInfoData({
        typeCode: 'zzcc-hyyxqk-sjzt',
        params: {
          // .
          startTime: dayjs().startOf('month').format('YYYY-MM-DD'),
          endTime: dayjs().endOf('month').format('YYYY-MM-DD'),
          sshy: '环境卫生',
        },
      }),
    {
      refreshDeps: [time],
    },
  );
    //问题来源
    const { data: sjly } = useRequest(
      () =>
        services.DataBase.getSjdzInfoData({
          typeCode: 'zzcc-hyyxqk-sjly',
          params: {
            // .
            startTime: dayjs().startOf('month').format('YYYY-MM-DD'),
            endTime: dayjs().endOf('month').format('YYYY-MM-DD'),
            sshy: '环境卫生',
          },
        }),
      {
        refreshDeps: [time],
      },
    );
  console.log(sjly);

  const items = useMemo(() => {
    return [
      {
        key: '2',
        name: '处置中',
        count: sjzt?.data?.data?.records?.[0]?.blz,
        unit: '件',
      },
      {
        key: '1',
        name: '超时',
        count: 12,
        unit: '件',
      },
      {
        key: '3',
        name: '已办结',
        count: sjzt?.data?.data?.records?.[0]?.ja,
        unit: '件',
      },
      {
        key: '3',
        name: '办结率',
        count: (
          (sjzt?.data?.data?.records?.[0]?.ja /
            sjzt?.data?.data?.records?.[0]?.zs) *
          100
        ).toFixed(2),
        unit: '%',
      },
    ];
  }, [sjzt]);
  const issue = useMemo(() => {
    return [
      {
        name: '行走成都',
        value: 16,
        perpent: 16,
        color: '#8edc70',
      },
      {
        name: '车载AI智能上报',
        value: 16,
        perpent: 16,
        color: '#8edc70',
      },
      {
        name: '监督员巡查上报',
        value: 16,
        perpent: 16,
        color: '#8edc70',
      },
      {
        name: '市容环卫中心上报',
        value: 16,
        perpent: 16,
        color: '#8edc70',
      },
    ];
  }, []);
  return (
    <div className={styles.container}>
      <div className={styles.leftWarp}>
        <div className={styles.dispose} onClick={() => {}}>
          <div className={styles.title}>
            <div className={styles.tLeft}>
              <span>巡查处置问题总数</span>
              <span className={styles.count}>4672</span>
              <span>件</span>
            </div>
            <div className={styles.tRignt}>
              <span>环比</span>
              <span>
                <CaretUpOutlined style={{ color: 'rgb(29, 187, 138)' }} />
                <CaretDownOutlined style={{ color: 'red' }} />
              </span>
              <span className={styles.count}>0.25</span>
              <span>%</span>
            </div>
          </div>
          <LineCharts
            data={[
              60, 50, 60, 70, 50, 70, 50, 60, 70, 50, 80, 50, 60, 70, 50, 60,
              50, 60, 70, 50,
            ]}
            style={{ width: 560, height: 80 }}
          />
        </div>

        <div className={styles.issueSource}>
          <div className={styles.title}>
            <span>主要问题来源</span>
          </div>

          <div className={styles.content}>
            <div>
              <Chart
                style={{ width: 112, height: 112 }}
                data={[
                  {
                    value: 20,
                    name: '行走成都',
                  },
                  {
                    value: 30,
                    name: '车载ai智能上报',
                  },
                ]}
                color={['#8edc70', '#ff9b5d', '#9e8fff', '#ffe335']}
              />
            </div>
            <div className={styles.cardWarp}>
              {issue?.map((item) => {
                return (
                  <div className={styles.card}>
                    <div
                      className={styles.dot}
                      style={{ background: item.color }}
                    ></div>
                    <div className={styles.cont}>
                      <div className={styles.name}>{item?.name}</div>
                      <div style={{ marginTop: 8 }}>
                        <span>
                          <span className={styles.count}>{item?.value}</span>
                          <span>件</span>
                        </span>
                        <span>
                          <span className={styles.count}> {item?.perpent}</span>

                          <span>%</span>
                        </span>
                      </div>
                    </div>
                  </div>
                );
              })}
            </div>
          </div>
        </div>

        <div className={styles.areaTop3}>
          <div className={styles.title}>高发类型TOP3</div>

          <div className={styles.content}>
            {[
              { percent: 80, value: 20, name: '高新区' },
              { percent: 80, value: 20, name: '高新区' },
              { percent: 80, value: 20, name: '高新区' },
            ].map((item, index) => {
              return (
                <div className={styles.litsItem} key={index}>
                  <Flex justify="space-between">
                    <div className={styles.name}>{item.name}</div>
                    <Space size={10} className={styles.numBox}>
                      <div className={styles.num}>
                        <span>{item?.value}</span>
                        <span>件</span>
                      </div>
                      <div className={styles.num}>
                        <span>{Number(item?.percent ?? 0).toFixed(2)}</span>
                        <span>%</span>
                      </div>
                    </Space>
                  </Flex>

                  <Progress
                    size={{ height: 15 }}
                    percent={item?.percent}
                    showInfo={false}
                    strokeColor={{ from: '#79FFD1', to: '#00B9FF' }}
                    status="active"
                  />
                </div>
              );
            })}
          </div>
        </div>
      </div>
      <div className={styles.rightWarp}>
        <div className={styles.infoWarp}>
          {items?.map((item) => {
            return (
              <div
                key={item.key}
                className={styles.items}
                onClick={() => {
                  dispatch.push('SanitationEvent');
                }}
              >
                <span className={styles.name}>{item?.name}</span>
                <div>
                  <span className={styles.count}>{item?.count}</span>
                  <span className={styles.unit}>{item?.unit}</span>
                </div>
              </div>
            );
          })}
        </div>
        <div className={styles.timeLineWarp}>
          <div className={styles.title}>高发时段分析</div>
          <TimeLineCharts
            data={[
              60, 50, 60, 70, 50, 70, 50, 60, 70, 50, 80, 50, 60, 70, 50, 60,
              50, 60, 70, 50,
            ]}
            style={{ width: 560, height: 180 }}
          />
        </div>
        <div className={styles.dispAreaTop5}>
          <div className={styles.title}>
            <span>高发区域TOP3</span>
            <Tabs
              style={{
                background: 'transparent',
                height: '30px',
              }}
              itemStyle={{
                borderRadius: '25px',
                background: 'rgba(7, 50, 93, 0.8)',
                fontSize: '16px',
                marginLeft: 8,
              }}
              onChange={() => {}}
              itemkey={'key'}
              items={[
                {
                  key: 'mainClass',
                  label: '全部',
                },
                {
                  key: 'subClass',
                  label: '5+2城区',
                },
                {
                  key: 'sub1Class',
                  label: '其他城区',
                },
              ]}
            />
          </div>

          <div className={styles.content}>
            {[{ percent: 80, value: 20, name: '高新区' }].map((item, index) => {
              return (
                <div className={styles.litsItem} key={index}>
                  <Flex justify="space-between">
                    <div className={styles.name}>{item.name}</div>
                    <Space size={10} className={styles.numBox}>
                      <div className={styles.num}>
                        <span>{item?.value}</span>
                        <span>件</span>
                      </div>
                      <div className={styles.num}>
                        <span>{Number(item?.percent ?? 0).toFixed(2)}</span>
                        <span>%</span>
                      </div>
                    </Space>
                  </Flex>

                  <Progress
                    size={{ height: 15 }}
                    percent={item?.percent}
                    showInfo={false}
                    strokeColor={{ from: '#79FFD1', to: '#00B9FF' }}
                    status="active"
                  />
                </div>
              );
            })}
          </div>
        </div>
      </div>
    </div>
  );
};
export default memo(SanitationDisp);
