import Modal from '@/components/HncyModal';
import Tabs from '@/components/Tabs';

import services from '@/services';
import { useRequest } from 'ahooks';
import { Flex, Image, List, Spin } from 'antd';
import { useState } from 'react';
import InfiniteScroll from 'react-infinite-scroll-component';
import styles from './index.less';

const CgftEvent = ({ singleType }: { singleType: string }) => {
  // 事件详情弹窗
  const [detailModalOpt, setDetailModalOpt] = useState<{
    open: boolean;
    title: string;
    eventId: string;
  }>({
    open: false,
    title: '',
    eventId: '',
  });

  //事件列表
  const [listData, setListData] = useState<any>({
    items: [],
    loading: true,
    total: 0,
    page: 1,
    hasNext: false,
  });

  const [fetchParams, setFetchParams] = useState<any>({
    pageNo: 0,
    pageSize: 10,
  });
  const { data } = useRequest(
    () =>
      services.DataBase.getSjdzInfoData({
        typeCode: 'zzcc-aq-yjxx',
        data: {
          ...fetchParams,
        },
      }),
    {
      refreshDeps: [fetchParams],
      onSuccess: (res) => {
        console.log(res?.data?.data);
        const data = res?.data?.data;
        const list = [
          ...listData?.items,
          ...data?.records?.map((item: any) => ({
            ...item,
            standardEventTitle: item?.riskdescription,
            caseStatusText: item?.status,
            reportTime: item?.risktime,
            collectionModeName: item?.sourceType,
            position: item?.region_name + item?.name,
          })),
        ];

        setListData({
          hasNext: list?.length < data?.page?.total,
          items: list,
        });
      },
    },
  );

  return (
    <div className={styles.wrap}>
      <div className={styles.searchWarp}>
        <Tabs
          style={{
            background: 'transparent',
            height: '30px',
          }}
          itemStyle={{
            borderRadius: '25px',
            background: 'rgba(7, 50, 93, 0.8)',
            fontSize: '16px',
            marginLeft: 8,
          }}
          onChange={() => {}}
          itemkey={'key'}
          items={[
            {
              key: 'mainClass',
              label: '全部',
            },
            {
              key: 'subClass',
              label: '处置中',
            },
            {
              key: 'sub1Class',
              label: '已结案',
            },
          ]}
        />
         <Tabs
          style={{
            background: 'transparent',
            height: '30px',
          }}
          itemStyle={{
            borderRadius: '25px',
            background: 'rgba(7, 50, 93, 0.8)',
            fontSize: '16px',
            marginLeft: 8,
          }}
          onChange={() => {}}
          itemkey={'key'}
          items={[
            {
              key: 'mainClass',
              label: '时限正常',
            },
            {
              key: 'subClass',
              label: '超时',
            },
           
          ]}
        />
      </div>
      <div id={'scrollableDiv1'}>
        <InfiniteScroll
          style={{
            height: 650,
            overflow: 'auto',
          }}
          height={650}
          dataLength={listData.items?.length ?? 0}
          hasMore={listData?.hasNext}
          scrollableTarget={'scrollableDiv1'}
          loader={
            <div style={{ textAlign: 'center' }}>
              <Spin />
            </div>
          }
          next={() => {
            console.log('222');
            fetchParams.pageNo++;
            setFetchParams({ ...fetchParams });
          }}
        >
          <List
            grid={{ column: 4, gutter: 20 }}
            dataSource={listData.items}
            loading={false}
            renderItem={(item: any) => (
              <List.Item key={item.eventId}>
                <div className={styles.cardWrap}>
                  <Image
                    src={item?.photosZWW}
                    width={'100%'}
                    height={'160px'}
                    style={{ objectFit: 'cover' }}
                  />
                  <div className={styles.info} onClick={() => {}}>
                    <p className={styles.cardText}>
                      {item.standardEventTitle ?? '无标题'}
                    </p>
                    <Flex align="center">
                      <span className={styles.status}>
                        {item.caseStatusText}
                      </span>
                      {(item.collectionModeName || item.eventTypeName) && (
                        <span className={styles.type}>
                          {item.collectionModeName || item.eventTypeName}
                        </span>
                      )}
                    </Flex>
                    <div>
                      <span>上报时间：</span>
                      <span>{item.reportTime}</span>
                    </div>
                    <div className={styles.textellipsis}>
                      <span>发生位置：</span>
                      <span>{item?.position}</span>
                    </div>
                  </div>
                </div>
              </List.Item>
            )}
          />
        </InfiniteScroll>
      </div>
      {/* <EventPicList
        listData={listData}
        listHeight={640}
        setParams={(page) => {
          fetchParams.current.page = page;
          getEventsList();
        }}
        handleDetail={(details) => {
          setDetailModalOpt({
            open: true,
            title: '事件详情',
            eventId: details.eventId,
          });
        }}
      /> */}
      {/* <Modal
        open={detailModalOpt?.open}
        title={detailModalOpt?.title}
        onCancel={() =>
          setDetailModalOpt({ open: false, title: '', eventId: '' })
        }
        width={'fit-content'}
        height={950}
      >
        <EventDetail eventId={detailModalOpt?.eventId} />
      </Modal> */}
    </div>
  );
};

export default CgftEvent;
