import Chart from '@/components/PieChart/Chart';
import services from '@/services';
import { formatNumber } from '@/utils/ui';
import { useRequest } from 'ahooks';
import { memo, useMemo } from 'react';
import BothwayBar from '../../components/BothwayBar';
import { useGlobalModalServices } from '../../provider';
import styles from './index.less';

const SanitationDisp = () => {
  const { dispatch } = useGlobalModalServices();
  const colors: string[] = [
    'rgb(255, 117, 203)',
    '#dfc1ae',
    '#8bd3ff',
    '#40fff2',
    '#73ed95',
    '#ccffb1',
    '#ffe07e',
    '#ff9369',
    '#c89594',
    '#f59cff',
    '#aa7dff'
  ];
  //环卫车辆
  const { data: clzs } = useRequest(() =>
    services.DataBase.getSjdzInfoData({
      typeCode: 'zzcc-clzs',
    }),
  );
  console.log(clzs);

  const issue = useMemo(() => {
    return [
      {
        name: '女性',
        value: 16,
        perpent: 16,
        color: '#ff9b5d',
      },
      {
        name: '男性',
        value: 16,
        perpent: 16,
        color: 'rgb(50, 177, 255)',
      },
    ];
  }, []);

  const vehicleList = useMemo(() => {
    return [
      {
        name: '作业车辆',
        value: 16,
        perpent: 16,
        color: 'rgb(125, 255, 233)',
      },
      {
        name: '环卫收运车辆',
        value: 16,
        perpent: 16,
        color: 'rgb(104, 190, 133)',
      },
      {
        name: 'xx',
        value: 16,
        perpent: 16,
        color: 'rgb(254, 148, 144)',
      },
    ];
  }, []);
  return (
    <div className={styles.container}>
      <div className={styles.leftWarp}>
        <div className={styles.issueSource}>
          <div className={styles.title}>
            <span>环卫人员</span>
          </div>

          <div className={styles.content}>
            <Chart
              style={{ width: 159, height: 159 }}
              data={issue}
              color={issue?.map((item) => item?.color)}
            />

            <div className={styles.cardWarp}>
              {issue?.map((item) => {
                return (
                  <div className={styles.card}>
                    <div
                      className={styles.dot}
                      style={{ background: item.color }}
                    ></div>
                    <div className={styles.cont}>
                      <div className={styles.name}>{item?.name}</div>
                      <div style={{ marginTop: 8 }}>
                        <span>
                          <span className={styles.count}>{item?.value}</span>
                          <span>人</span>
                        </span>
                        <span>
                          <span className={styles.count}> {item?.perpent}</span>

                          <span>%</span>
                        </span>
                      </div>
                    </div>
                  </div>
                );
              })}
            </div>
          </div>
        </div>

        <div className={styles.vehicle}>
          <div className={styles.title}>
            <span>
              全市共有环卫车辆
              <span style={{ marginLeft: 5, marginRight: 5 }}>
                {
                  formatNumber(
                    clzs?.data?.data?.records?.[0]?.totalVehicleCount,
                  )?.num
                }
              </span>
              {
                formatNumber(
                  clzs?.data?.data?.records?.[0]?.totalVehicleCount,
                  {
                    one: '辆',
                    myriad: '万辆',
                  },
                )?.unit
              }
            </span>
          </div>

          <div className={styles.content}>
            <Chart
              style={{ width: 128, height: 128 }}
              data={clzs?.data?.data?.records?.[0]?.types?.map((item) => ({
                name: item?.carGradeName,
                value: item?.vehicleCount,
              }))}
              color={colors}
            />

            <div className={styles.cardWarp}>
              {clzs?.data?.data?.records?.[0]?.types?.map((item, index) => {
                return (
                  <div className={styles.card} key={index}>
                    <div
                      className={styles.dot}
                      style={{ background: colors[index] }}
                    ></div>
                    <div className={styles.cont}>
                      <div className={styles.name}>{item?.carGradeName}</div>
                      <div style={{ marginTop: 8 }}>
                        <span>
                          <span className={styles.count}>
                            {formatNumber(item?.vehicleCount)?.num}
                          </span>
                          <span>
                            {
                              formatNumber(item?.vehicleCount, {
                                one: '辆',
                                myriad: '万辆',
                              })?.unit
                            }
                          </span>
                        </span>
                        <span>
                          <span
                            className={styles.count}
                            style={{ marginLeft: 10 }}
                          >
                            {(
                              (item.vehicleCount /
                                clzs?.data?.data?.records?.[0]
                                  ?.totalVehicleCount) *
                              100
                            ).toFixed(2)}
                          </span>

                          <span>%</span>
                        </span>
                      </div>
                    </div>
                  </div>
                );
              })}
            </div>
          </div>
        </div>
      </div>
      <div className={styles.rightWarp}>
        <div className={styles.personnel}>
          <div className={styles.title}>各类型环卫从业人员数量及占比</div>

          <div className={styles.content}>
            <Chart
              style={{ width: 159, height: 159 }}
              data={vehicleList}
              color={vehicleList?.map((item) => item?.color)}
            />

            <div className={styles.cardWarp}>
              {vehicleList?.map((item) => {
                return (
                  <div className={styles.card}>
                    <div style={{ display: 'flex', alignItems: 'center' }}>
                      <div
                        className={styles.dot}
                        style={{ background: item.color }}
                      ></div>
                      <div className={styles.name}>{item?.name}</div>
                    </div>

                    <div>
                      <span>
                        <span className={styles.count}>{item?.value}</span>
                        <span>辆</span>
                      </span>
                      <span>
                        <span className={styles.count}> {item?.perpent}</span>

                        <span>%</span>
                      </span>
                    </div>
                  </div>
                );
              })}
            </div>
          </div>
        </div>

        <div className={styles.perYear}>
          <div className={styles.title}>
            <span>各年龄区间环卫从业人员分布</span>
            <div className={styles.rW}>
              <div
                style={{
                  display: 'flex',
                  alignItems: 'center',
                  marginRight: 20,
                }}
              >
                <div className={styles.square}></div>男
              </div>
              <div style={{ display: 'flex', alignItems: 'center' }}>
                <div
                  className={styles.square}
                  style={{ background: 'rgb(255, 155, 93)' }}
                ></div>
                女
              </div>
            </div>
          </div>
          <BothwayBar />
        </div>
      </div>
    </div>
  );
};
export default memo(SanitationDisp);
