import AdministPunish from './modals/AdministPunish';
import AdministPunishDetails from './modals/AdministPunish/AdministPunishDetails';
import AdministPunishList from './modals/AdministPunish/AdministPunishList';
import AnalysisCompletionRate from './modals/AnalysisCompletionRate';
import AreaSynergy from './modals/AreaSynergy';
import AreaSynergyDetails from './modals/AreaSynergy/AreaSynergyDetails';
import AreaSynergyList from './modals/AreaSynergy/AreaSynergyList';
import Category from './modals/Category';
import CgftEvent from './modals/CgftEvent';
import CollectionEvent from './modals/CollectionEvent';
import DataActivity from './modals/DataActivity';
import DataBase from './modals/DataBase';
import DataGovernance from './modals/DataGovernance';
import DifficultEvents from './modals/DifficultEvents';
import DistrictIndex from './modals/DistrictIndex';
import DyaPatrol from './modals/DyaPatrol';
import DyaPatrolDetails from './modals/DyaPatrol/DyaPatrolDetails';
import DyaPatrolList from './modals/DyaPatrol/DyaPatrolList';
import EquipResource from './modals/EquipResource';
import EventDetail from './modals/EventDetail';
import GeneralSituation from './modals/GeneralSituation';
import KeyArea from './modals/KeyArea';
import KeyAreaDetail from './modals/KeyAreaDetail';
import OtherEvent from './modals/OtherEvent';
import SanitationDisp from './modals/SanitationDisp';
import SanitationEvent from './modals/SanitationEvent';
import SanitationResource from './modals/SanitationResource';
import SignModel from './modals/SignModel';
import ToDisposed from './modals/ToDisposed';
import UrbanOperation from './modals/UrbanOperation';
import { ModalMapping } from './type';

export type ModalKey = keyof typeof Registry.RegistryList;

/** @see ModalMapping 弹窗注册在这里 */
export default class Registry {
  static readonly RegistryList = {
    /**
     * 行业指数弹窗
     * @module DistrictIndex
     * @see DistrictIndex.RightBox
     */
    districtIndex: {
      defaultConfig: {
        w: 2756,
        h: 846,
        title: '行业指数',
      },
      defaultProps: {},
      modal: DistrictIndex,
    },
    /**
     * 体征模型
     * @module overview
     * @see NewHome - > NewLeftSidebar -> CityRealTimeCQI
     */
    SignModel: {
      defaultConfig: {
        w: 1470,
        h: 846,
        title: '体征模型',
      },
      defaultProps: {},
      modal: SignModel,
    },
    /**
     * 诚管24高速通道
     * @module overview
     * @see
     */
    CgftEvent: {
      defaultConfig: {
        w: 1772,
        h: 846,
      },
      defaultProps: {
        singleType: '1',
      },
      modal: CgftEvent,
    },
    /**
     * 智慧蓉城提级通道
     * @module overview
     * @see
     */
    UrbanOperation: {
      defaultConfig: {
        w: 1772,
        h: 846,
      },
      defaultProps: {
        eventType: '5',
      },
      modal: UrbanOperation,
    },
    /**
     * 行业自闭环通道处置情况
     * @module overview
     * @see
     */
    OtherEvent: {
      defaultConfig: {
        w: 1772,
        h: 846,
      },
      defaultProps: {
        isOther: '1',
      },
      modal: OtherEvent,
    },
    /**
     * 待处置
     * @module overview
     * @see
     */
    ToDisposed: {
      defaultConfig: {
        w: 1772,
        h: 846,
      },
      defaultProps: {},
      modal: ToDisposed,
    },
    /**
     * 完成率
     * @module overview
     * @see
     */
    CompletionRate: {
      defaultConfig: {
        w: 1772,
        h: 846,
      },
      defaultProps: {},
      modal: AnalysisCompletionRate,
    },
    /**
     * 整体情况
     * @module overview
     * @see
     */
    GeneralSituation: {
      defaultConfig: {
        w: 1772,
        h: 846,
      },
      defaultProps: {},
      modal: GeneralSituation,
    },
    /**
     * 整体情况
     * @module overview
     * @see
     */
    CollectionEvent: {
      defaultConfig: {
        w: 1772,
        h: 846,
      },
      defaultProps: {},
      modal: CollectionEvent,
    },
    /**
     * 疑难问题
     * @module overview
     * @see
     */
    DifficultEvents: {
      defaultConfig: {
        w: 2000,
        h: 846,
      },
      defaultProps: {},
      modal: DifficultEvents,
    },

    /**
     * EventDetail
     * @module Event
     * @see Event -> EventDetail
     */
    EventDetail: {
      defaultConfig: {
        // w: 1465,
        h: 950,
        title: '事件详情',
      },
      defaultProps: {},
      modal: EventDetail,
    },

    /**
     * 体征模型
     * @module overview
     * @see NewHome - > NewLeftSidebar -> CityRealTimeCQI
     */
    Category: {
      defaultConfig: {
        w: 1470,
        h: 846,
      },
      defaultProps: {},
      modal: Category,
    },

    keyArea: {
      defaultConfig: {
        w: 2771,
        h: 846,
        title: '重点区域',
        keepalive: true,
      },
      defaultProps: {},
      modal: KeyArea,
    },

    KeyAreaDetail: {
      defaultConfig: {
        w: 2771,
        h: 846,
        title: '重点区域详情',
      },
      defaultProps: {},
      modal: KeyAreaDetail,
    },
    DataBase: {
      defaultConfig: {
        w: 2343,
        h: 846,
        title: '数据仓库',
      },
      defaultProps: {},
      modal: DataBase,
    },
    DataActivity: {
      defaultConfig: {
        w: 1616,
        h: 935,
        title: '城市管理数据标签体系',
      },
      defaultProps: {},
      modal: DataActivity,
    },
    DataGovernance: {
      defaultConfig: {
        w: 1424,
        h: 846,
        title: '城管数据治理概况',
      },
      defaultProps: {},
      modal: DataGovernance,
    },
    AdministPunish: {
      defaultConfig: {
        w: 1480,
        h: 858,
        title: '行政处罚',
      },
      defaultProps: {},
      modal: AdministPunish,
    },
    AdministPunishList: {
      defaultConfig: {
        w: 1480,
        h: 858,
        title: '行政处罚列表',
      },
      defaultProps: {},
      modal: AdministPunishList,
    },
    AdministPunishDetails: {
      defaultConfig: {
        w: 1480,
        h: 858,
        title: '行政处罚详情',
      },
      defaultProps: {},
      modal: AdministPunishDetails,
    },

    DyaPatrol: {
      defaultConfig: {
        w: 1380,
        h: 858,
        title: '巡查处置列表',
      },
      defaultProps: {},
      modal: DyaPatrol,
    },
    DyaPatrolList: {
      defaultConfig: {
        w: 1480,
        h: 858,
        title: '巡查处置列表',
      },
      defaultProps: {},
      modal: DyaPatrolList,
    },
    DyaPatrolDetails: {
      defaultConfig: {
        w: 1480,
        h: 858,
        title: '巡查处置问题详情',
      },
      defaultProps: {},
      modal: DyaPatrolDetails,
    },
    AreaSynergy: {
      defaultConfig: {
        w: 1380,
        h: 858,
        title: '市区协同处理',
      },
      defaultProps: {},
      modal: AreaSynergy,
    },
    AreaSynergyList: {
      defaultConfig: {
        w: 1480,
        h: 858,
        title: '市区协调处置事件列表',
      },
      defaultProps: {},
      modal: AreaSynergyList,
    },
    AreaSynergyDetails: {
      defaultConfig: {
        w: 1480,
        h: 858,
        title: '巡查处置问题详情',
      },
      defaultProps: {},
      modal: AreaSynergyDetails,
    },
    EquipResource: {
      defaultConfig: {
        w: 1380,
        h: 865,
        title: '总队执法装备资源分配情况',
      },
      defaultProps: {},
      modal: EquipResource,
    },
    SanitationDisp: {
      defaultConfig: {
        w: 1320,
        h: 865,
        title: '环境卫生问题处置情况',
      },
      defaultProps: {},
      modal: SanitationDisp,
    },
    SanitationEvent: {
      defaultConfig: {
        w: 1320,
        h: 865,
        title: '问题列表',
      },
      defaultProps: {},
      modal: SanitationEvent,
    },
    SanitationResource: {
      defaultConfig: {
        w: 1450,
        h: 885,
        title: '环卫资源',
      },
      defaultProps: {},
      modal: SanitationResource,
    },
  };

  static get(modalKey: ModalKey) {
    return Registry.RegistryList[modalKey];
  }
}
