import DescriptionItem from '@/components/DescriptionItem';
import TopSarch from '@/pages/GlobalModalServices/modals/SanitationDisp/TopSarch';
import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';
import services from '@/services';
import { formatNumber } from '@/utils/ui';
import { useModel } from '@umijs/max';
import { useRequest } from 'ahooks';
import { Flex, Space } from 'antd';
import dayjs from 'dayjs';
import React, { useEffect, useState } from 'react';
import CountUp from 'react-countup';
import LineCharts from '../LineCharts';
import styles from './index.less';

const EnvironmentalHealth: React.FC = () => {
  const { initialState } = useModel('@@initialState');
  const { areaId } = initialState;
  const { dispatch } = useGlobalModalServices();
  const [eventCount, setEventCount] = useState(0);
  const [searchTime, setSearchTime] = useState({
    startTime: dayjs().format('YYYY-MM-DD'),
    endTime: dayjs().format('YYYY-MM-DD'),
  });
  const [eventChartData, setEventChartData] = useState([]);

  const commonValueStyle = {
    background: 'linear-gradient(180deg, #AAFFF6 0%, #25BBFF 100%)',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
    fontFamily: 'D-DIN',
    fontSize: '30px',
    fontWeight: 700,
    lineHeight: 1.1,
  };

  const commonLabelStyle = {
    color: '#BCCEE9',
    // fontFamily: '微软雅黑',
    fontSize: '20px',
    fontWeight: 400,
    lineHeight: 1.1,
  };

  const labelStyle = {
    ...commonLabelStyle,
    width: '85%',
  };

  const commonUnitStyle = {
    color: '#BCCEE9',
    // fontFamily: '微软雅黑',
    fontSize: '20px',
    fontWeight: 400,
    lineHeight: 1.1,
  };

  const getData = () => {
    const params = {
      industry: '02',
      dateType: 'today',
      objectId: areaId,
    };
    services.Physicalsign.getNormalEventCountApi(params).then((res: any) => {
      console.log(res);
      if (res.code === 200) {
        setEventCount(res.data?.problemCount);
      }
    });
  };

  const getEchartsData = () => {
    const params = {
      industry: '02',
      dateType: 'month',
      objectId: areaId,
    };
    services.Physicalsign.getNormalEventTrendApi(params).then((res: any) => {
      console.log(res);
      if (res.code === 200) {
        setEventChartData(res.data);
      }
    });
  };

  useEffect(() => {
    getData();
    getEchartsData();
  }, []);
  //环卫车辆
  const { data: clzs } = useRequest(() =>
    services.DataBase.getSjdzInfoData({
      typeCode: 'zzcc-clzs',
    }),
  );
  return (
    <div className={styles.container}>
      <Flex vertical gap={20}>
        <Space
          size={15}
          onClick={() => {
            dispatch.push('SanitationDisp', {
              headerLeft: () => {
                return (
                  <TopSarch
                    onChange={(e) => {
                      setSearchTime(e);
                    }}
                  />
                );
              },
              props: {
                time: searchTime,
              },
            });
          }}
        >
          <span className={styles.label} style={commonLabelStyle}>
            今日发现问题
          </span>
          <CountUp
            className={styles.value}
            end={Number(eventCount)}
            style={commonValueStyle}
            preserveValue
            decimals={0}
          />
          {/* <div style={commonValueStyle}>--</div> */}
          <span className={styles.unit} style={commonUnitStyle}>
            件
          </span>
        </Space>
        <div>
          <LineCharts data={eventChartData || []} />
        </div>
        <Flex justify="space-between">
          <div
            onClick={() => {
              dispatch.push('SanitationResource', {
                // props: {
                //   data: selected,
                //   indexs: indexs,
                // },
              });
            }}
          >
            {' '}
            <DescriptionItem
              value={5.49}
              name="环卫人员"
              unit="万人"
              valueStyle={commonValueStyle}
              labelStyle={commonLabelStyle}
              unitStyle={commonUnitStyle}
              decimals={2}
            />
          </div>
          <div
            onClick={() => {
              dispatch.push('SanitationResource', {
                // props: {
                //   data: selected,
                //   indexs: indexs,
                // },
              });
            }}
          >
            <DescriptionItem
              value={
                formatNumber(clzs?.data?.data?.records?.[0]?.totalVehicleCount)
                  ?.num
              }
              name="环卫车辆"
              unit="万辆"
              valueStyle={commonValueStyle}
              labelStyle={commonLabelStyle}
              unitStyle={commonUnitStyle}
              decimals={2}
            />
          </div>
        </Flex>
      </Flex>
    </div>
  );
};

export default EnvironmentalHealth;
